
==========
dxfgrabber
==========

.. image:: https://readthedocs.org/projects/pip/badge/
   :target: https://dxfgrabber.readthedocs.io
   :alt: Read The Docs

.. image:: https://img.shields.io/pypi/l/dxfgrabber.svg
   :target: https://pypi.python.org/pypi/dxfgrabber/
   :alt: License

.. image:: https://img.shields.io/pypi/pyversions/dxfgrabber.svg
   :target: https://pypi.python.org/pypi/dxfgrabber/
   :alt: Python Versions

.. image:: https://img.shields.io/pypi/wheel/dxfgrabber.svg
   :target: https://pypi.python.org/pypi/dxfgrabber/
   :alt: Wheel Status

.. image:: https://img.shields.io/pypi/status/dxfgrabber.svg
   :target: https://pypi.python.org/pypi/dxfgrabber/
   :alt: Status

Abstract
--------

A Python library to grab information from DXF drawings - all DXF versions supported.


Installation
============

    python setup.py install

Documentation
=============

http://dxfgrabber.readthedocs.io

http://pythonhosted.org/dxfgrabber/

Source at bitbucket.org:

http://bitbucket.org/mozman/dxfgrabber

mozman -- <mozman@gmx.at>
